import json
import logging
import os
import requests
import urllib3
import clients as app_clients
from botocore.exceptions import ClientError

urllib3.disable_warnings()
logger = logging.getLogger("migrate_localdev_connectors")
logger.setLevel(logging.INFO)
formatter = logging.Formatter("%(asctime)s %(levelname)s - %(message)s")
handler_console = logging.StreamHandler()
handler_console.setFormatter(formatter)
logger.addHandler(handler_console)

def main():
    env = 'localdev'
    #base_client_url = os.environ.get('ES_URL', 'http://elasticsearch:9200')
    #base_client = app_clients.BaseClient(base_client_url)
    #base_client.setData()
    dynamo_client = app_clients.DynamoDbClient(env)
    dynamo_client.setClientEnvironment()
    logger.info("-------------------------------------------------------------------------------------")
    for filename in os.listdir('connectors/orgs/1'):
        if filename.endswith(".json"):
            try:
                f = open("connectors/orgs/1/{}".format(filename), 'r')
            except IOError:
                print("ERROR: An IO error occured when reading from file roles/{}".format(filename))
            else:
                try:
                    text = f.read()
                    service_connector_json = json.loads(text)
                    service_connector_name = service_connector_json['connector_name']
                    service_connector_json['role_urn'] = service_connector_json['role_urn'].format(
                        org_key="R76KWHRN")
                    service_connector_urn = service_connector_json['role_urn']

                    #logger.info("Creating'%s' custom connector in ElasticSearch...."
                    #            % service_connector_name)
                    with open('local/service-connector-es-template.json', 'r') as es_file:
                        custom_connector_template = json.load(es_file)
                        custom_connector_template['apiKey'] = custom_connector_template['apiKey'].format(
                            serviceConnectorSecret=service_connector_name)
                        custom_connector_template['connectorId'] = custom_connector_template['connectorId'].format(
                            connectorId=service_connector_name
                        )
                        custom_connector_template['name'] = service_connector_name

                        #create_custom_connector_response = base_client.put(
                        #    path="/connector/confer/1_{}?routing=1".format(custom_connector_template['apiKey']),
                        #    payload=custom_connector_template)

                        #create_custom_connector_response.raise_for_status()

                        logger.info("Creating Grant for '%s'..." % service_connector_name)
                        with open('local/service-connector-grant-template.json', 'r') as grants_file:
                            grants_template = json.load(grants_file)
                            grants_template['principal']['S'] = grants_template['principal']['S'].format(
                                principal='psc:cnn:R76KWHRN:{}'.format(custom_connector_template['connectorId'])
                            )
                            grants_template['roles']['SS'][0] = grants_template['roles']['SS'][0].format(
                                role=service_connector_urn
                            )
                            try:
                                dynamo_client.put_item("localdev_access_grants", grants_template)
                                logger.info("X-Auth-Token: %s/%s" % (
                                    custom_connector_template['apiKey'], custom_connector_template['connectorId']))
                            except ClientError as ex:
                                logger.error("Put item failed for service connector %s, error: %s)" %
                                             (service_connector_name, ex.response))
                except requests.HTTPError as ex:
                    logger.error("Request failed (json=%s)" % ex.response.__dict__, exc_info=ex)
        logger.info("-------------------------------------------------------------------------------------")
    logger.info("Done migrating local service connectors")


if __name__ == "__main__":
    main()
